@@ -29,139 +29,6 @@
 
 #include "tracker-utils.h"
 
-inline gboolean
-tracker_is_empty_string (const char *str)
-{
-	return str == NULL || str[0] == '\0';
-}
-
-inline gboolean
-tracker_is_blank_string (const char *str)
-{
-	register const gchar *p;
-
-	if (str == NULL || str[0] == '\0') {
-		return TRUE;
-	}
-
-	for (p = str; *p; p = g_utf8_next_char (p)) {
-		register gunichar c;
-
-		c = g_utf8_get_char (p);
-
-		if (!g_unichar_isspace (c)) {
-			return FALSE;
-		}
-	}
-
-	return TRUE;
-}
-
-guint
-tracker_seconds_estimate (gdouble seconds_elapsed,
-                          guint   items_done,
-                          guint   items_remaining)
-{
-	/* Return 0 if unknown */
-	if (seconds_elapsed <= 0 ||
-	    items_done < 1 ||
-	    items_remaining < 1) {
-		return 0;
-	}
-
-	/* A estimate is an estimate, and full seconds is probably
-	 * more correct than a floating point value... */
-	return (guint)((seconds_elapsed / items_done) * items_remaining);
-}
-
-gchar *
-tracker_seconds_estimate_to_string (gdouble   seconds_elapsed,
-                                    gboolean  short_string,
-                                    guint     items_done,
-                                    guint     items_remaining)
-{
-	guint estimate;
-
-	estimate = tracker_seconds_estimate (seconds_elapsed,
-	                                     items_done,
-	                                     items_remaining);
-
-	if (estimate == 0)
-		return g_strdup (_("unknown time"));
-
-	return tracker_seconds_to_string (estimate, short_string);
-}
-
-gchar *
-tracker_seconds_to_string (gdouble  seconds_elapsed,
-                           gboolean short_string)
-{
-	GString *s;
-	gchar   *str;
-	gdouble  total;
-	gint     days, hours, minutes, seconds;
-
-	g_return_val_if_fail (seconds_elapsed >= 0.0, g_strdup (_("less than one second")));
-
-	total = seconds_elapsed;
-
-	seconds  = (gint) total % 60;
-	total   /= 60;
-	minutes  = (gint) total % 60;
-	total   /= 60;
-	hours    = (gint) total % 24;
-	days     = (gint) total / 24;
-
-	s = g_string_new ("");
-
-	if (short_string) {
-		if (days) { /* Translators: this is %d days */
-			g_string_append_printf (s, _(" %dd"), days);
-		}
-
-		if (hours) { /* Translators: this is %2.2d hours */
-			g_string_append_printf (s, _(" %2.2dh"), hours);
-		}
-
-		if (minutes) { /* Translators: this is %2.2d minutes */
-			g_string_append_printf (s, _(" %2.2dm"), minutes);
-		}
-
-		if (seconds) { /* Translators: this is %2.2d seconds */
-			g_string_append_printf (s, _(" %2.2ds"), seconds);
-		}
-	} else {
-		if (days) {
-			g_string_append_printf (s, ngettext (" %d day", " %d days", days), days);
-		}
-
-		if (hours) {
-			g_string_append_printf (s, ngettext (" %2.2d hour", " %2.2d hours", hours), hours);
-		}
-
-		if (minutes) {
-			g_string_append_printf (s, ngettext (" %2.2d minute", " %2.2d minutes", minutes), minutes);
-		}
-
-		if (seconds) {
-			g_string_append_printf (s, ngettext (" %2.2d second", " %2.2d seconds", seconds), seconds);
-		}
-	}
-
-	str = g_string_free (s, FALSE);
-
-	if (str[0] == '\0') {
-		g_free (str);
-		str = g_strdup (_("less than one second"));
-	} else {
-		g_strchug (str);
-	}
-
-	return str;
-}
-
-
-
 /**
  * tracker_strhex:
  * @data: The input array of bytes
