@@ -300,7 +300,7 @@ char *
 tracker_namespace_manager_print_turtle (TrackerNamespaceManager *self)
 {
 	TrackerNamespaceManagerPrivate *priv;
-	GString *result = g_string_new ("");
+	GString *result;
 	GHashTableIter iter;
 	const char *prefix;
 	const char *namespace;
@@ -309,6 +309,8 @@ tracker_namespace_manager_print_turtle (TrackerNamespaceManager *self)
 
 	priv = GET_PRIVATE (self);
 
+	result = g_string_new ("");
+
 	g_hash_table_iter_init (&iter, priv->prefix_to_namespace);
 	while (g_hash_table_iter_next (&iter, (gpointer *)&prefix, (gpointer *)&namespace)) {
 		g_string_append_printf (result, "@prefix %s: <%s> .\n", prefix, namespace);
