@@ -96,6 +96,9 @@ void tracker_resource_set_identifier (TrackerResource *self, const char *identif
 TRACKER_AVAILABLE_IN_ALL
 gint tracker_resource_identifier_compare_func (TrackerResource *resource, const char *identifier);
 
+TRACKER_AVAILABLE_IN_ALL
+GList *tracker_resource_get_properties (TrackerResource *resource);
+
 TRACKER_AVAILABLE_IN_ALL
 char *tracker_resource_print_turtle(TrackerResource *self, TrackerNamespaceManager *namespaces);
 
@@ -105,6 +108,15 @@ char *tracker_resource_print_sparql_update (TrackerResource *self, TrackerNamesp
 TRACKER_AVAILABLE_IN_ALL
 char *tracker_resource_print_jsonld (TrackerResource *self, TrackerNamespaceManager *namespaces);
 
+TRACKER_AVAILABLE_IN_ALL
+GVariant * tracker_resource_serialize (TrackerResource *resource);
+
+TRACKER_AVAILABLE_IN_ALL
+TrackerResource * tracker_resource_deserialize (GVariant *variant);
+
+TRACKER_AVAILABLE_IN_3_1
+gboolean tracker_resource_get_property_overwrite (TrackerResource *resource, const gchar *property_uri);
+
 G_END_DECLS
 
 #endif /* __LIBTRACKER_RESOURCE_H__ */
